Package 'splithalfr'

Title: Estimate Split-Half Reliabilities
Description: Estimates split-half reliabilities for scoring algorithms of cognitive tasks and questionnaires. The 'splithalfr' supports researcher-provided scoring algorithms, with six vignettes illustrating how on included datasets. The package provides four splitting methods (first-second, odd-even, permutated, Monte Carlo), the option to stratify splits by task design, a number of reliability coefficients, the option to sub-sample data, and bootstrapped confidence intervals.
Authors: Thomas Pronk [aut, cre]
Maintainer: Thomas Pronk <[email protected]>
License: GPL-3
Version: 3.0.0
Built: 2026-06-10 08:06:46 UTC
Source: https://github.com/tpronk/splithalfr

Help Index